@@ -8,6 +8,9 @@ from typing import Any, Dict, List, Optional, Sequence, Set, Union
 
 import nbformat
 import papermill
+from papermill.engines import papermill_engines
+from papermill.iorw import load_notebook_node, write_ipynb
+
 from dagster import (
     InputDefinition,
     OpDefinition,
@@ -18,8 +21,8 @@ from dagster import (
     seven,
 )
 from dagster.core.definitions.events import AssetMaterialization, Failure, RetryRequested
-from dagster.core.definitions.metadata import MetadataEntry
-from dagster.core.definitions.reconstructable import ReconstructablePipeline
+from dagster.core.definitions.metadata import MetadataEntry, MetadataValue
+from dagster.core.definitions.reconstruct import ReconstructablePipeline
 from dagster.core.definitions.utils import validate_tags
 from dagster.core.execution.context.compute import SolidExecutionContext
 from dagster.core.execution.context.input import build_input_context
@@ -31,8 +34,6 @@ from dagster.seven import get_system_temp_directory
 from dagster.utils import mkdir_p, safe_tempfile_path
 from dagster.utils.backcompat import rename_warning
 from dagster.utils.error import serializable_error_info_from_exc_info
-from papermill.engines import papermill_engines
-from papermill.iorw import load_notebook_node, write_ipynb
 
 from .compat import ExecutionError
 from .engine import DagstermillEngine
@@ -256,7 +257,10 @@ def _dm_compute(
                         asset_key=(asset_key_prefix + [f"{name}_output_notebook"]),
                         description="Location of output notebook in file manager",
                         metadata_entries=[
-                            MetadataEntry.fspath(executed_notebook_materialization_path)
+                            MetadataEntry(
+                                "path",
+                                value=MetadataValue.path(executed_notebook_materialization_path),
+                            )
                         ],
                     )
 
