@@ -12,26 +12,31 @@ from dagster import (
     SolidDefinition,
     TypeCheck,
     check,
-    seven,
 )
-from dagster.core.definitions.dependency import SolidHandle
-from dagster.core.definitions.reconstructable import ReconstructablePipeline
-from dagster.core.definitions.resource import ScopedResourcesBuilder
-from dagster.core.execution.api import create_execution_plan, scoped_pipeline_context
+from dagster.core.definitions.dependency import NodeHandle
+from dagster.core.definitions.events import RetryRequested
+from dagster.core.definitions.pipeline_base import InMemoryPipeline
+from dagster.core.definitions.reconstruct import ReconstructablePipeline
+from dagster.core.definitions.resource_definition import ScopedResourcesBuilder
+from dagster.core.events import DagsterEvent
+from dagster.core.execution.api import scoped_pipeline_context
+from dagster.core.execution.plan.outputs import StepOutputHandle
+from dagster.core.execution.plan.plan import ExecutionPlan
 from dagster.core.execution.resources_init import (
     get_required_resource_keys_to_init,
     resource_initialization_event_generator,
 )
 from dagster.core.instance import DagsterInstance
-from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
+from dagster.core.storage.pipeline_run import DagsterRun, PipelineRunStatus
+from dagster.core.system_config.objects import ResolvedRunConfig
 from dagster.core.utils import make_new_run_id
 from dagster.loggers import colored_console_logger
 from dagster.serdes import unpack_value
-from dagster.utils import EventGenerationManager
+from dagster.utils import EventGenerationManager, ensure_gen
 
 from .context import DagstermillExecutionContext, DagstermillRuntimeExecutionContext
 from .errors import DagstermillError
-from .serialize import PICKLE_PROTOCOL, read_value, write_value
+from .serialize import PICKLE_PROTOCOL
 
 
 class DagstermillResourceEventGenerationManager(EventGenerationManager):
@@ -63,13 +68,15 @@ class Manager:
 
     def _setup_resources(
         self,
-        execution_plan,
-        environment_config,
-        pipeline_run,
+        resource_defs,
+        resource_configs,
         log_manager,
+        execution_plan,
+        pipeline_run,
         resource_keys_to_init,
         instance,
-        resource_instances_to_override,
+        emit_persistent_events,
+        pipeline_def_for_backwards_compat,
     ):
         """
         Drop-in replacement for
@@ -77,13 +84,15 @@ class Manager:
         `DagstermillResourceEventGenerationManager` and explicitly calls `teardown` on it
         """
         generator = resource_initialization_event_generator(
-            execution_plan,
-            environment_config,
-            pipeline_run,
-            log_manager,
-            resource_keys_to_init,
-            instance,
-            resource_instances_to_override,
+            resource_defs=resource_defs,
+            resource_configs=resource_configs,
+            log_manager=log_manager,
+            execution_plan=execution_plan,
+            pipeline_run=pipeline_run,
+            resource_keys_to_init=resource_keys_to_init,
+            instance=instance,
+            emit_persistent_events=emit_persistent_events,
+            pipeline_def_for_backwards_compat=pipeline_def_for_backwards_compat,
         )
         self.resource_manager = DagstermillResourceEventGenerationManager(
             generator, ScopedResourcesBuilder
@@ -99,6 +108,7 @@ class Manager:
         pipeline_run_dict=None,
         solid_handle_kwargs=None,
         instance_ref_dict=None,
+        step_key=None,
     ):
         """Reconstitutes a context for dagstermill-managed execution.
 
@@ -118,6 +128,7 @@ class Manager:
         check.dict_param(executable_dict, "executable_dict")
         check.dict_param(solid_handle_kwargs, "solid_handle_kwargs")
         check.dict_param(instance_ref_dict, "instance_ref_dict")
+        check.str_param(step_key, "step_key")
 
         pipeline = ReconstructablePipeline.from_dict(executable_dict)
         pipeline_def = pipeline.get_definition()
@@ -125,30 +136,35 @@ class Manager:
         try:
             instance_ref = unpack_value(instance_ref_dict)
             instance = DagsterInstance.from_ref(instance_ref)
-        except Exception as err:  # pylint: disable=broad-except
+        except Exception as err:
             raise DagstermillError(
                 "Error when attempting to resolve DagsterInstance from serialized InstanceRef"
             ) from err
 
         pipeline_run = unpack_value(pipeline_run_dict)
 
-        solid_handle = SolidHandle.from_dict(solid_handle_kwargs)
-        solid_def = pipeline_def.get_solid(solid_handle).definition
+        solid_handle = NodeHandle.from_dict(solid_handle_kwargs)
+        solid = pipeline_def.get_solid(solid_handle)
+        solid_def = solid.definition
 
         self.marshal_dir = marshal_dir
         self.in_pipeline = True
         self.solid_def = solid_def
         self.pipeline = pipeline
 
-        execution_plan = create_execution_plan(
+        resolved_run_config = ResolvedRunConfig.build(
+            pipeline_def, run_config, mode=pipeline_run.mode
+        )
+
+        execution_plan = ExecutionPlan.build(
             self.pipeline,
-            run_config,
-            mode=pipeline_run.mode,
+            resolved_run_config,
             step_keys_to_execute=pipeline_run.step_keys_to_execute,
         )
 
         with scoped_pipeline_context(
             execution_plan,
+            pipeline,
             run_config,
             pipeline_run,
             instance,
@@ -158,12 +174,16 @@ class Manager:
         ) as pipeline_context:
             self.context = DagstermillRuntimeExecutionContext(
                 pipeline_context=pipeline_context,
-                solid_config=run_config.get("solids", {}).get(solid_def.name, {}).get("config"),
+                pipeline_def=pipeline_def,
+                solid_config=run_config.get("solids", {}).get(solid.name, {}).get("config"),
                 resource_keys_to_init=get_required_resource_keys_to_init(
                     execution_plan,
-                    pipeline_context.intermediate_storage_def,
+                    pipeline_def,
+                    resolved_run_config,
                 ),
-                solid_name=solid_def.name,
+                solid_name=solid.name,
+                solid_handle=solid_handle,
+                step_context=pipeline_context.for_step(execution_plan.get_step_by_key(step_key)),
             )
 
         return self.context
@@ -178,7 +198,7 @@ class Manager:
                 use to construct the context. Specify this if you would like a context constructed
                 with specific ``resource_defs`` or ``logger_defs``. By default, an ephemeral mode
                 with a console logger will be constructed.
-            run_config(Optional[dict]): The environment config dict with which to construct
+            run_config(Optional[dict]): The config dict with which to construct
                 the context.
 
         Returns:
@@ -216,7 +236,7 @@ class Manager:
         # construct stubbed PipelineRun for notebook exploration...
         # The actual pipeline run during pipeline execution will be serialized and reconstituted
         # in the `reconstitute_pipeline_context` call
-        pipeline_run = PipelineRun(
+        pipeline_run = DagsterRun(
             pipeline_name=pipeline_def.name,
             run_id=run_id,
             run_config=run_config,
@@ -230,9 +250,14 @@ class Manager:
         self.solid_def = solid_def
         self.pipeline = pipeline_def
 
-        execution_plan = create_execution_plan(self.pipeline, run_config, mode=mode_def.name)
+        resolved_run_config = ResolvedRunConfig.build(pipeline_def, run_config, mode=mode_def.name)
+
+        pipeline = InMemoryPipeline(pipeline_def)
+        execution_plan = ExecutionPlan.build(pipeline, resolved_run_config)
+
         with scoped_pipeline_context(
             execution_plan,
+            pipeline,
             run_config,
             pipeline_run,
             DagsterInstance.ephemeral(),
@@ -241,12 +266,15 @@ class Manager:
 
             self.context = DagstermillExecutionContext(
                 pipeline_context=pipeline_context,
+                pipeline_def=pipeline_def,
                 solid_config=solid_config,
                 resource_keys_to_init=get_required_resource_keys_to_init(
                     execution_plan,
-                    pipeline_context.intermediate_storage_def,
+                    pipeline_def,
+                    resolved_run_config,
                 ),
                 solid_name=solid_def.name,
+                solid_handle=NodeHandle(solid_def.name, parent=None),
             )
 
         return self.context
@@ -272,10 +300,20 @@ class Manager:
                 f"Expected one of {[str(output_def.name) for output_def in self.solid_def.output_defs]}"
             )
 
-        dagster_type = self.solid_def.output_def_named(output_name).dagster_type
+        # pass output value cross process boundary using io manager
+        step_context = self.context._step_context  # pylint: disable=protected-access
+        # Note: yield_result currently does not support DynamicOutput
+        step_output_handle = StepOutputHandle(
+            step_key=step_context.step.key, output_name=output_name
+        )
+        output_context = step_context.get_output_context(step_output_handle)
+        io_manager = step_context.get_io_manager(step_output_handle)
 
-        out_file = os.path.join(self.marshal_dir, f"output-{output_name}")
-        scrapbook.glue(output_name, write_value(dagster_type, value, out_file))
+        # Note that we assume io manager is symmetric, i.e handle_input(handle_output(X)) == X
+        io_manager.handle_output(output_context, value)
+
+        # record that the output has been yielded
+        scrapbook.glue(output_name, "")
 
     def yield_event(self, dagster_event):
         """Yield a dagster event directly from notebook code.
@@ -283,14 +321,21 @@ class Manager:
         When called interactively or in development, returns its input.
 
         Args:
-            dagster_event (Union[:class:`dagster.Materialization`, :class:`dagster.ExpectationResult`, :class:`dagster.TypeCheck`, :class:`dagster.Failure`]):
+            dagster_event (Union[:class:`dagster.AssetMaterialization`, :class:`dagster.ExpectationResult`, :class:`dagster.TypeCheck`, :class:`dagster.Failure`, :class:`dagster.RetryRequested`]):
                 An event to yield back to Dagster.
         """
-        check.inst_param(
-            dagster_event,
-            "dagster_event",
-            (AssetMaterialization, Materialization, ExpectationResult, TypeCheck, Failure),
+        valid_types = (
+            Materialization,
+            AssetMaterialization,
+            ExpectationResult,
+            TypeCheck,
+            Failure,
+            RetryRequested,
         )
+        if not isinstance(dagster_event, valid_types):
+            raise DagstermillError(
+                f"Received invalid type {dagster_event} in yield_event. Expected a Dagster event type, one of {valid_types}."
+            )
 
         if not self.in_pipeline:
             return dagster_event
@@ -309,9 +354,15 @@ class Manager:
         if self.resource_manager is not None:
             self.resource_manager.teardown()
 
-    def load_parameter(self, input_name, input_value):
-        input_def = self.solid_def.input_def_named(input_name)
-        return read_value(input_def.dagster_type, seven.json.loads(input_value))
+    def load_input_parameter(self, input_name: str):
+        # load input from source
+        step_context = self.context._step_context  # pylint: disable=protected-access
+        step_input = step_context.step.step_input_named(input_name)
+        for event_or_input_value in ensure_gen(step_input.source.load_input_object(step_context)):
+            if isinstance(event_or_input_value, DagsterEvent):
+                continue
+            else:
+                return event_or_input_value
 
 
 MANAGER_FOR_NOTEBOOK_INSTANCE = Manager()
